#' Expand a data frame into a matrix suitable for BART
#'
#' Goes through the data frame and creates a numeric matrix suitable for use
#' with BART. The numeric variables are collected into the a first set of
#' columns and the factors are expanded into dummies and added as columns after
#' the numeric columns. Note that a factor with k levels is expressed as k
#' dummies (not k-1 as in a linear model).
#'
#' Note that the R package BART has a function \code{bartModelMatrix} which does
#' a similar thing as \code{bartModMat}. \code{bartModMat} is a simplified
#' version.
#'
#' @param X data frame to be converted to a matrix by exanding factors to
#'   dummies
#' @return The matrix with numeric variables in the first set of columns and
#'   factor dummies following.
#' @examples
#' xdf = data.frame(x1=1:5,x2=as.factor(c(1,2,3,1,2)))
#' x = bartModMat(xdf)
#' print(xdf)
#' print(x)
#' @export
bartModMat <- function(X) {
p <- ncol(X)
Xnum <- NULL
Xfac <- NULL
for (i in 1:p) {
   xnm <- names(X)[i]
   print(xnm)
   if (is.factor(X[[i]])) {
      Xtemp <- nnet::class.ind(X[[i]])
      colnames(Xtemp) <- paste(xnm, ".", levels(X[[i]]), sep = "")
      Xfac <- cbind(Xfac, Xtemp)
   } else {
      Xnum <- cbind(Xnum, X[[i]])
      colnames(Xnum)[ncol(Xnum)] <- xnm
   }
}
cat("bartModMat, dimension of numeric variables:\n")
print(dim(Xnum))
cat("bartModMat, dimension of categorical variables:\n")
print(dim(Xfac))

return(cbind(Xnum, Xfac))
}
